==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/workbench_instance/WorkbenchInstanceGceSetupDataDisks.java <==
package com.hashicorp.cdktf.providers.google.workbench_instance;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:43.279Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.workbenchInstance.WorkbenchInstanceGceSetupDataDisks")
@software.amazon.jsii.Jsii.Proxy(WorkbenchInstanceGceSetupDataDisks.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface WorkbenchInstanceGceSetupDataDisks extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional. Input only. Disk encryption method used on the boot and data disks, defaults to GMEK. Possible values: ["GMEK", "CMEK"].
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#disk_encryption WorkbenchInstance#disk_encryption}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDiskEncryption() {
        return null;
    }

    /**
     * Optional.
     * <p>
     * The size of the disk in GB attached to this VM instance,
     * up to a maximum of 64000 GB (64 TB). If not specified, this defaults to
     * 100.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#disk_size_gb WorkbenchInstance#disk_size_gb}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDiskSizeGb() {
        return null;
    }

    /**
     * Optional. Input only. Indicates the type of the disk. Possible values: ["PD_STANDARD", "PD_SSD", "PD_BALANCED", "PD_EXTREME"].
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#disk_type WorkbenchInstance#disk_type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDiskType() {
        return null;
    }

    /**
     * 'Optional.
     * <p>
     * Input only. The KMS key used to encrypt the disks,
     * only applicable if disk_encryption is CMEK. Format: 'projects/{project_id}/locations/{location}/keyRings/{key_ring_id}/cryptoKeys/{key_id}'
     * Learn more about using your own encryption keys.'
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#kms_key WorkbenchInstance#kms_key}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getKmsKey() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WorkbenchInstanceGceSetupDataDisks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WorkbenchInstanceGceSetupDataDisks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<WorkbenchInstanceGceSetupDataDisks> {
        java.lang.String diskEncryption;
        java.lang.String diskSizeGb;
        java.lang.String diskType;
        java.lang.String kmsKey;

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getDiskEncryption}
         * @param diskEncryption Optional. Input only. Disk encryption method used on the boot and data disks, defaults to GMEK. Possible values: ["GMEK", "CMEK"].
         *                       Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#disk_encryption WorkbenchInstance#disk_encryption}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder diskEncryption(java.lang.String diskEncryption) {
            this.diskEncryption = diskEncryption;
            return this;
        }

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getDiskSizeGb}
         * @param diskSizeGb Optional.
         *                   The size of the disk in GB attached to this VM instance,
         *                   up to a maximum of 64000 GB (64 TB). If not specified, this defaults to
         *                   100.
         *                   
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#disk_size_gb WorkbenchInstance#disk_size_gb}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder diskSizeGb(java.lang.String diskSizeGb) {
            this.diskSizeGb = diskSizeGb;
            return this;
        }

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getDiskType}
         * @param diskType Optional. Input only. Indicates the type of the disk. Possible values: ["PD_STANDARD", "PD_SSD", "PD_BALANCED", "PD_EXTREME"].
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#disk_type WorkbenchInstance#disk_type}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder diskType(java.lang.String diskType) {
            this.diskType = diskType;
            return this;
        }

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getKmsKey}
         * @param kmsKey 'Optional.
         *               Input only. The KMS key used to encrypt the disks,
         *               only applicable if disk_encryption is CMEK. Format: 'projects/{project_id}/locations/{location}/keyRings/{key_ring_id}/cryptoKeys/{key_id}'
         *               Learn more about using your own encryption keys.'
         *               
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/workbench_instance#kms_key WorkbenchInstance#kms_key}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder kmsKey(java.lang.String kmsKey) {
            this.kmsKey = kmsKey;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WorkbenchInstanceGceSetupDataDisks}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public WorkbenchInstanceGceSetupDataDisks build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WorkbenchInstanceGceSetupDataDisks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WorkbenchInstanceGceSetupDataDisks {
        private final java.lang.String diskEncryption;
        private final java.lang.String diskSizeGb;
        private final java.lang.String diskType;
        private final java.lang.String kmsKey;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.diskEncryption = software.amazon.jsii.Kernel.get(this, "diskEncryption", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.diskSizeGb = software.amazon.jsii.Kernel.get(this, "diskSizeGb", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.diskType = software.amazon.jsii.Kernel.get(this, "diskType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.kmsKey = software.amazon.jsii.Kernel.get(this, "kmsKey", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.diskEncryption = builder.diskEncryption;
            this.diskSizeGb = builder.diskSizeGb;
            this.diskType = builder.diskType;
            this.kmsKey = builder.kmsKey;
        }

        @Override
        public final java.lang.String getDiskEncryption() {
            return this.diskEncryption;
        }

        @Override
        public final java.lang.String getDiskSizeGb() {
            return this.diskSizeGb;
        }

        @Override
        public final java.lang.String getDiskType() {
            return this.diskType;
        }

        @Override
        public final java.lang.String getKmsKey() {
            return this.kmsKey;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDiskEncryption() != null) {
                data.set("diskEncryption", om.valueToTree(this.getDiskEncryption()));
            }
            if (this.getDiskSizeGb() != null) {
                data.set("diskSizeGb", om.valueToTree(this.getDiskSizeGb()));
            }
            if (this.getDiskType() != null) {
                data.set("diskType", om.valueToTree(this.getDiskType()));
            }
            if (this.getKmsKey() != null) {
                data.set("kmsKey", om.valueToTree(this.getKmsKey()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.workbenchInstance.WorkbenchInstanceGceSetupDataDisks"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WorkbenchInstanceGceSetupDataDisks.Jsii$Proxy that = (WorkbenchInstanceGceSetupDataDisks.Jsii$Proxy) o;

            if (this.diskEncryption != null ? !this.diskEncryption.equals(that.diskEncryption) : that.diskEncryption != null) return false;
            if (this.diskSizeGb != null ? !this.diskSizeGb.equals(that.diskSizeGb) : that.diskSizeGb != null) return false;
            if (this.diskType != null ? !this.diskType.equals(that.diskType) : that.diskType != null) return false;
            return this.kmsKey != null ? this.kmsKey.equals(that.kmsKey) : that.kmsKey == null;
        }

        @Override
        public final int hashCode() {
            int result = this.diskEncryption != null ? this.diskEncryption.hashCode() : 0;
            result = 31 * result + (this.diskSizeGb != null ? this.diskSizeGb.hashCode() : 0);
            result = 31 * result + (this.diskType != null ? this.diskType.hashCode() : 0);
            result = 31 * result + (this.kmsKey != null ? this.kmsKey.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/workbench_instance/WorkbenchInstanceGceSetupDataDisks.java <==
package com.hashicorp.cdktf.providers.google.workbench_instance;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:17.523Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.workbenchInstance.WorkbenchInstanceGceSetupDataDisks")
@software.amazon.jsii.Jsii.Proxy(WorkbenchInstanceGceSetupDataDisks.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface WorkbenchInstanceGceSetupDataDisks extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional. Input only. Disk encryption method used on the boot and data disks, defaults to GMEK. Possible values: ["GMEK", "CMEK"].
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#disk_encryption WorkbenchInstance#disk_encryption}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDiskEncryption() {
        return null;
    }

    /**
     * Optional.
     * <p>
     * The size of the disk in GB attached to this VM instance,
     * up to a maximum of 64000 GB (64 TB). If not specified, this defaults to
     * 100.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#disk_size_gb WorkbenchInstance#disk_size_gb}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDiskSizeGb() {
        return null;
    }

    /**
     * Optional. Input only. Indicates the type of the disk. Possible values: ["PD_STANDARD", "PD_SSD", "PD_BALANCED", "PD_EXTREME"].
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#disk_type WorkbenchInstance#disk_type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDiskType() {
        return null;
    }

    /**
     * 'Optional.
     * <p>
     * The KMS key used to encrypt the disks,
     * only applicable if disk_encryption is CMEK. Format: 'projects/{project_id}/locations/{location}/keyRings/{key_ring_id}/cryptoKeys/{key_id}'
     * Learn more about using your own encryption keys.'
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#kms_key WorkbenchInstance#kms_key}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getKmsKey() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WorkbenchInstanceGceSetupDataDisks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WorkbenchInstanceGceSetupDataDisks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<WorkbenchInstanceGceSetupDataDisks> {
        java.lang.String diskEncryption;
        java.lang.String diskSizeGb;
        java.lang.String diskType;
        java.lang.String kmsKey;

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getDiskEncryption}
         * @param diskEncryption Optional. Input only. Disk encryption method used on the boot and data disks, defaults to GMEK. Possible values: ["GMEK", "CMEK"].
         *                       Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#disk_encryption WorkbenchInstance#disk_encryption}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder diskEncryption(java.lang.String diskEncryption) {
            this.diskEncryption = diskEncryption;
            return this;
        }

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getDiskSizeGb}
         * @param diskSizeGb Optional.
         *                   The size of the disk in GB attached to this VM instance,
         *                   up to a maximum of 64000 GB (64 TB). If not specified, this defaults to
         *                   100.
         *                   
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#disk_size_gb WorkbenchInstance#disk_size_gb}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder diskSizeGb(java.lang.String diskSizeGb) {
            this.diskSizeGb = diskSizeGb;
            return this;
        }

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getDiskType}
         * @param diskType Optional. Input only. Indicates the type of the disk. Possible values: ["PD_STANDARD", "PD_SSD", "PD_BALANCED", "PD_EXTREME"].
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#disk_type WorkbenchInstance#disk_type}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder diskType(java.lang.String diskType) {
            this.diskType = diskType;
            return this;
        }

        /**
         * Sets the value of {@link WorkbenchInstanceGceSetupDataDisks#getKmsKey}
         * @param kmsKey 'Optional.
         *               The KMS key used to encrypt the disks,
         *               only applicable if disk_encryption is CMEK. Format: 'projects/{project_id}/locations/{location}/keyRings/{key_ring_id}/cryptoKeys/{key_id}'
         *               Learn more about using your own encryption keys.'
         *               
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/workbench_instance#kms_key WorkbenchInstance#kms_key}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder kmsKey(java.lang.String kmsKey) {
            this.kmsKey = kmsKey;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WorkbenchInstanceGceSetupDataDisks}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public WorkbenchInstanceGceSetupDataDisks build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WorkbenchInstanceGceSetupDataDisks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WorkbenchInstanceGceSetupDataDisks {
        private final java.lang.String diskEncryption;
        private final java.lang.String diskSizeGb;
        private final java.lang.String diskType;
        private final java.lang.String kmsKey;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.diskEncryption = software.amazon.jsii.Kernel.get(this, "diskEncryption", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.diskSizeGb = software.amazon.jsii.Kernel.get(this, "diskSizeGb", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.diskType = software.amazon.jsii.Kernel.get(this, "diskType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.kmsKey = software.amazon.jsii.Kernel.get(this, "kmsKey", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.diskEncryption = builder.diskEncryption;
            this.diskSizeGb = builder.diskSizeGb;
            this.diskType = builder.diskType;
            this.kmsKey = builder.kmsKey;
        }

        @Override
        public final java.lang.String getDiskEncryption() {
            return this.diskEncryption;
        }

        @Override
        public final java.lang.String getDiskSizeGb() {
            return this.diskSizeGb;
        }

        @Override
        public final java.lang.String getDiskType() {
            return this.diskType;
        }

        @Override
        public final java.lang.String getKmsKey() {
            return this.kmsKey;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDiskEncryption() != null) {
                data.set("diskEncryption", om.valueToTree(this.getDiskEncryption()));
            }
            if (this.getDiskSizeGb() != null) {
                data.set("diskSizeGb", om.valueToTree(this.getDiskSizeGb()));
            }
            if (this.getDiskType() != null) {
                data.set("diskType", om.valueToTree(this.getDiskType()));
            }
            if (this.getKmsKey() != null) {
                data.set("kmsKey", om.valueToTree(this.getKmsKey()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.workbenchInstance.WorkbenchInstanceGceSetupDataDisks"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WorkbenchInstanceGceSetupDataDisks.Jsii$Proxy that = (WorkbenchInstanceGceSetupDataDisks.Jsii$Proxy) o;

            if (this.diskEncryption != null ? !this.diskEncryption.equals(that.diskEncryption) : that.diskEncryption != null) return false;
            if (this.diskSizeGb != null ? !this.diskSizeGb.equals(that.diskSizeGb) : that.diskSizeGb != null) return false;
            if (this.diskType != null ? !this.diskType.equals(that.diskType) : that.diskType != null) return false;
            return this.kmsKey != null ? this.kmsKey.equals(that.kmsKey) : that.kmsKey == null;
        }

        @Override
        public final int hashCode() {
            int result = this.diskEncryption != null ? this.diskEncryption.hashCode() : 0;
            result = 31 * result + (this.diskSizeGb != null ? this.diskSizeGb.hashCode() : 0);
            result = 31 * result + (this.diskType != null ? this.diskType.hashCode() : 0);
            result = 31 * result + (this.kmsKey != null ? this.kmsKey.hashCode() : 0);
            return result;
        }
    }
}
